@@ -8,7 +8,10 @@ import os
 import numpy.ctypeslib as npct
 import ctypes as ct
 p = os.path.join(Path(__file__).parent.absolute(),'cfunctions')
-cfunct = npct.load_library('ctypes.dll',p)
+if os.name=='nt':
+	cfunct = npct.load_library('ctypes_c.dll',p)
+else:
+	cfunct = npct.load_library('ctypes.so',p)
 
 import numpy as np
 import calculus_ll as cll
